@@ -1,4 +1,4 @@
-from keras_cv_attention_models.cotnet.cotnet import CotNet, CotNet50, CotNet101, CotNetSE50D, CotNetSE101D, CotNetSE152D, cot_attention
+from keras_cv_attention_models.cotnet.cotnet import CotNet, CotNet50, CotNet101, CotNetSE50D, CotNetSE101D, CotNetSE152D, cot_attention, set_global_tpu_test
 
 
 __head_doc__ = """
@@ -7,7 +7,6 @@ Paper [PDF 2107.12292 Contextual Transformer Networks for Visual Recognition](ht
 """
 
 __tail_doc__ = """  bn_after_attn: boolean value if add `batchnorm + activation` layers after attention layer. Default `True`.
-  avg_pool_down: boolean value if use `AvgPool2D` in shortcut branch. Default `True` for `ResNetD` model like.
   input_shape: it should have exactly 3 inputs channels, like `(224, 224, 3)`.
   num_classes: number of classes to classify images into. Set `0` to exclude top layers.
   activation: activation used in whole model, default `relu`.
