@@ -6,9 +6,11 @@ PRETRAINED_DICT = {
     "regnety_080": {"imagenet": "537d6e015de12be18458776e6d911555"},
     "regnety_160": {"imagenet": "7a039bfb1e006571991a19b5e3fbd0d1"},
     "regnety_320": {"imagenet": "20fbbf6de39635b89ae284ac0574c4cf"},
-    "regnetz_b": {"imagenet": "9f03b9e885c6918db54374b74f355eb9"},
-    "regnetz_c": {"imagenet": "cfa0cf70aa724d8e79633641208d7d39"},
-    "regnetz_d": {"imagenet": "b76e7c68a309a3697ffb5f30c0aeeea6"},
+    "regnetz_b16": {"imagenet": "9f03b9e885c6918db54374b74f355eb9"},
+    "regnetz_c16": {"imagenet": "cfa0cf70aa724d8e79633641208d7d39"},
+    "regnetz_d32": {"imagenet": "b76e7c68a309a3697ffb5f30c0aeeea6"},
+    "regnetz_d8": {"imagenet": "1fa2de5606f33b503cedda4689b8bddd"},
+    "regnetz_e8": {"imagenet": "7d0a85b287ad041e0446623c7070fa8f"},
 }
 
 
@@ -71,7 +73,7 @@ def RegNetY320(input_shape=(224, 224, 3), num_classes=1000, activation="relu", c
     return model
 
 
-def RegNetZB(input_shape=(224, 224, 3), num_classes=1000, activation="swish", classifier_activation="softmax", pretrained="imagenet", **kwargs):
+def RegNetZB16(input_shape=(224, 224, 3), num_classes=1000, activation="swish", classifier_activation="softmax", pretrained="imagenet", **kwargs):
     num_blocks = [2, 6, 12, 2]
     strides = [2, 2, 2, 2]
     out_channels = [48, 96, 192, 288]
@@ -86,12 +88,12 @@ def RegNetZB(input_shape=(224, 224, 3), num_classes=1000, activation="swish", cl
     group_size = 16
     shortcut_type = None
     output_num_features = 1536
-    model = AotNet(**locals(), model_name="regnetz_b", **kwargs)
+    model = AotNet(**locals(), model_name="regnetz_b16", **kwargs)
     reload_model_weights(model, pretrained_dict=PRETRAINED_DICT, sub_release="resnet_family", input_shape=input_shape, pretrained=pretrained)
     return model
 
 
-def RegNetZC(input_shape=(256, 256, 3), num_classes=1000, activation="swish", classifier_activation="softmax", pretrained="imagenet", **kwargs):
+def RegNetZC16(input_shape=(256, 256, 3), num_classes=1000, activation="swish", classifier_activation="softmax", pretrained="imagenet", **kwargs):
     num_blocks = [2, 6, 12, 2]
     strides = [2, 2, 2, 2]
     out_channels = [48, 96, 192, 288]
@@ -106,12 +108,12 @@ def RegNetZC(input_shape=(256, 256, 3), num_classes=1000, activation="swish", cl
     group_size = 16
     shortcut_type = None
     output_num_features = 1536
-    model = AotNet(**locals(), model_name="regnetz_c", **kwargs)
+    model = AotNet(**locals(), model_name="regnetz_c16", **kwargs)
     reload_model_weights(model, pretrained_dict=PRETRAINED_DICT, sub_release="resnet_family", input_shape=input_shape, pretrained=pretrained)
     return model
 
 
-def RegNetZD(input_shape=(256, 256, 3), num_classes=1000, activation="swish", classifier_activation="softmax", pretrained="imagenet", **kwargs):
+def RegNetZD32(input_shape=(256, 256, 3), num_classes=1000, activation="swish", classifier_activation="softmax", pretrained="imagenet", **kwargs):
     num_blocks = [3, 6, 12, 3]
     strides = [1, 2, 2, 2]
     out_channels = [64, 128, 256, 384]
@@ -127,6 +129,48 @@ def RegNetZD(input_shape=(256, 256, 3), num_classes=1000, activation="swish", cl
     group_size = 32
     shortcut_type = None
     output_num_features = 1792
-    model = AotNet(**locals(), model_name="regnetz_d", **kwargs)
+    model = AotNet(**locals(), model_name="regnetz_d32", **kwargs)
+    reload_model_weights(model, pretrained_dict=PRETRAINED_DICT, sub_release="resnet_family", input_shape=input_shape, pretrained=pretrained)
+    return model
+
+
+def RegNetZD8(input_shape=(256, 256, 3), num_classes=1000, activation="swish", classifier_activation="softmax", pretrained="imagenet", **kwargs):
+    num_blocks = [3, 6, 12, 3]
+    strides = [1, 2, 2, 2]
+    out_channels = [64, 128, 256, 384]
+    # timm bottle_in=True mode, the first ratio in each stack is `ratio * previous_channel`
+    hidden_channel_ratio = [[64 * 4 / 64, 4, 4], [64 * 4 / 128] + [4] * 5, [128 * 4 / 256] + [4] * 11, [256 * 4 / 384, 4, 4]]
+    use_block_output_activation = False  # timm linear_out=True mode
+    stem_type = "tiered"
+    stem_last_strides = 2
+    stem_width = 64
+    stem_downsample = False
+    se_ratio = 0.25
+    attn_params = {"activation": "relu"}
+    group_size = 8
+    shortcut_type = None
+    output_num_features = 1792
+    model = AotNet(**locals(), model_name="regnetz_d8", **kwargs)
+    reload_model_weights(model, pretrained_dict=PRETRAINED_DICT, sub_release="resnet_family", input_shape=input_shape, pretrained=pretrained)
+    return model
+
+
+def RegNetZE8(input_shape=(256, 256, 3), num_classes=1000, activation="swish", classifier_activation="softmax", pretrained="imagenet", **kwargs):
+    num_blocks = [3, 8, 16, 3]
+    strides = [1, 2, 2, 2]
+    out_channels = [96, 192, 384, 512]
+    # timm bottle_in=True mode, the first ratio in each stack is `ratio * previous_channel`
+    hidden_channel_ratio = [[64 * 4 / 96, 4, 4], [96 * 4 / 192] + [4] * 7, [192 * 4 / 384] + [4] * 15, [384 * 4 / 512, 4, 4]]
+    use_block_output_activation = False  # timm linear_out=True mode
+    stem_type = "tiered"
+    stem_last_strides = 2
+    stem_width = 64
+    stem_downsample = False
+    se_ratio = 0.25
+    attn_params = {"activation": "relu"}
+    group_size = 8
+    shortcut_type = None
+    output_num_features = 2048
+    model = AotNet(**locals(), model_name="regnetz_e8", **kwargs)
     reload_model_weights(model, pretrained_dict=PRETRAINED_DICT, sub_release="resnet_family", input_shape=input_shape, pretrained=pretrained)
     return model
